@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: buttons.c,v 1.39 2002/10/23 03:03:26 mej Exp $";
+static const char cvs_ident[] = "$Id: buttons.c,v 1.44 2004/06/25 21:52:00 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -91,7 +91,7 @@ buttonbar_t *bbar_create(void)
     xattr.colormap = cmap;
 
     cursor = XCreateFontCursor(Xdisplay, XC_left_ptr);
-    mask = EnterWindowMask | LeaveWindowMask | PointerMotionMask | ButtonMotionMask | ButtonPressMask | ButtonReleaseMask;
+    mask = KeyPressMask | EnterWindowMask | LeaveWindowMask | PointerMotionMask | ButtonMotionMask | ButtonPressMask | ButtonReleaseMask;
     gcvalue.foreground = xattr.border_pixel;
 
     bbar->font = load_font(etfonts[def_font_idx], "fixed", FONT_TYPE_X);
@@ -554,10 +554,12 @@ button_calc_size(buttonbar_t *bbar, button_t *button)
     }
 #ifdef PIXMAP_SUPPORT
     if (button->icon) {
-        unsigned short b = 0;
+        unsigned short b;
 
         if (bord) {
             b = button->h - bord->top - bord->bottom;
+        } else {
+            b = button->h;
         }
         imlib_context_set_image(button->icon->iml->im);
         button->icon_w = imlib_image_get_width();
@@ -1010,7 +1012,7 @@ bbar_show(buttonbar_t *bbar, unsigned char visible)
 }
 
 void
-bbar_show_all(char visible)
+bbar_show_all(signed char visible)
 {
     buttonbar_t *bbar;
 
