@@ -34,7 +34,7 @@
  * he guarantee anything whatsoever.
  *----------------------------------------------------------------------*/
 
-static const char cvs_ident[] = "$Id: command.c,v 1.91 2002/10/25 03:57:17 mej Exp $";
+static const char cvs_ident[] = "$Id: command.c,v 1.100 2004/03/11 13:59:44 mej Exp $";
 
 /* includes: */
 #include "config.h"
@@ -1045,10 +1045,12 @@ handle_child_signal(int sig)
     /* If the child that exited is the command we spawned, or if the
        child exited before fork() returned in the parent, it must be
        our immediate child that exited.  We exit gracefully. */
-    if (((pid == cmd_pid) && (cmd_pid != -1))
-        || ((pid == -1) && (errno == ECHILD) && (cmd_pid != -1))
-        || ((pid == 0) && (cmd_pid != -1) && ((kill(cmd_pid, 0)) < 0))) {
-        if (Options & Opt_pause) {
+    if ((cmd_pid != -1)
+        && ((pid == cmd_pid)
+            || ((pid == -1) && (errno == ECHILD))
+            || ((pid == 0) && ((kill(cmd_pid, 0)) < 0)))) {
+        cmd_pid = -1;
+        if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_PAUSE)) {
             paused = 1;
             return;
         }
@@ -1848,13 +1850,14 @@ xim_send_spot(void)
 static void
 xim_get_area(XRectangle * preedit_rect, XRectangle * status_rect, XRectangle * needed_rect)
 {
-    preedit_rect->x = needed_rect->width + (scrollbar_is_visible() && !(Options & Opt_scrollbar_right) ? (scrollbar_trough_width()) : 0);
+    preedit_rect->x = needed_rect->width + (scrollbar_is_visible() && !(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT))
+                                            ? (scrollbar_trough_width()) : (0));
     preedit_rect->y = Height2Pixel(TERM_WINDOW_GET_ROWS() - 1);
 
-    preedit_rect->width = Width2Pixel(TERM_WINDOW_GET_COLS() + 1) - needed_rect->width + (!(Options & Opt_scrollbar_right) ? (scrollbar_trough_width()) : 0);
+    preedit_rect->width = Width2Pixel(TERM_WINDOW_GET_COLS() + 1) - needed_rect->width + (!(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT)) ? (scrollbar_trough_width()) : 0);
     preedit_rect->height = Height2Pixel(1);
 
-    status_rect->x = (scrollbar_is_visible() && !(Options & Opt_scrollbar_right)) ? (scrollbar_trough_width()) : 0;
+    status_rect->x = (scrollbar_is_visible() && !(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT))) ? (scrollbar_trough_width()) : 0;
     status_rect->y = Height2Pixel(TERM_WINDOW_GET_ROWS() - 1);
 
     status_rect->width = needed_rect->width ? needed_rect->width : Width2Pixel(TERM_WINDOW_GET_COLS() + 1);
@@ -2143,6 +2146,7 @@ run_command(char **argv)
         PrivateModes |= PrivMode_scrollbar;
         SavedModes |= PrivMode_scrollbar;
     }
+    tt_winsize(ptyfd);
 #if DEBUG >= DEBUG_TTYMODE && defined(HAVE_TERMIOS_H)
     if (DEBUG_LEVEL >= DEBUG_TTYMODE) {
         debug_ttymode(&tio);
@@ -2188,7 +2192,7 @@ run_command(char **argv)
         tt_winsize(0);
 
         /* become virtual console, fail silently */
-        if (Options & Opt_console) {
+        if (BITFIELD_IS_SET(vt_options, VT_OPTIONS_CONSOLE)) {
             int fd = 1;
 
             privileges(INVOKE);
@@ -2253,7 +2257,7 @@ run_command(char **argv)
                 shell = "/bin/sh";
 
             argv0 = my_basename(shell);
-            if (Options & Opt_login_shell) {
+            if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_LOGIN_SHELL)) {
                 char *p = MALLOC(strlen(argv0) + 2);
 
                 p[0] = '-';
@@ -2268,7 +2272,7 @@ run_command(char **argv)
     }
 #ifdef UTMP_SUPPORT
     privileges(RESTORE);
-    if (Options & Opt_write_utmp) {
+    if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_WRITE_UTMP)) {
         add_utmp_entry(ttydev, display_name, ptyfd);
     }
     privileges(IGNORE);
@@ -2516,7 +2520,7 @@ err_msg(void *xd, int err, char *msg)
 {
 #if DEBUG >= DEBUG_ESCREEN
     if (DEBUG_LEVEL >= DEBUG_ESCREEN) {
-        char *sc[] = { "Copy mode", "Bell in", "Wuff,  Wuff!!" };
+        char *sc[] = { "Copy mode", "Bell in" };
         int n, nsc = sizeof(sc) / sizeof(char *);
 
         /* there are certain things that would make sense if we were displaying
@@ -2532,11 +2536,16 @@ err_msg(void *xd, int err, char *msg)
                 menu_dialog(NULL, msg, 0, NULL, NULL);
             }
         }
-    }
+    } else
 #endif
+
+    if (!BEG_STRCASECMP(msg, "Wuff")) {
+        /* screen beeped, so go ahead and use our normal beep. */
+        scr_bell();
+    }
+
     USE_VAR(xd);
     USE_VAR(err);
-    USE_VAR(msg);
     return NS_SUCC;
 }
 
@@ -2908,6 +2917,7 @@ escreen_init(char **argv)
     int ns_err;
     _ns_efuns *efuns;
     buttonbar_t *bbar;
+    spif_uchar_t old_pause = (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_PAUSE) ? (1) : (0));
 
     if (TermWin.screen_mode == NS_MODE_NONE) {
         return run_command(argv);
@@ -2931,6 +2941,7 @@ escreen_init(char **argv)
         bbar_add(bbar);
     }
 
+    BITFIELD_SET(eterm_options, ETERM_OPTIONS_PAUSE);
     if ((TermWin.screen = ns_attach_by_URL(rs_url, rs_hop, &efuns, &ns_err, bbar)) == NULL) {
         D_CMD(("ns_attach_by_URL(%s,%s) failed\n", rs_url, rs_hop));
         return -1;
@@ -2938,6 +2949,9 @@ escreen_init(char **argv)
     if (rs_delay >= 0) {
         TermWin.screen->delay = rs_delay;       /* more flexible ways later */
     }
+    if (!old_pause) {
+        BITFIELD_CLEAR(eterm_options, ETERM_OPTIONS_PAUSE);
+    }
 
     make_escreen_menu(bbar);
 
@@ -2978,7 +2992,7 @@ init_command(char **argv)
     init_locale();
 
 #ifdef META8_OPTION
-    meta_char = (Options & Opt_meta8 ? 0x80 : 033);
+    meta_char = (BITFIELD_IS_SET(vt_options, VT_OPTIONS_META8) ? 0x80 : 033);
 #endif
 
 #ifdef GREEK_SUPPORT
@@ -2994,7 +3008,8 @@ init_command(char **argv)
     }
     if ((cmd_fd = command_func(argv)) < 0) {
         print_error("Unable to run sub-command.\n");
-        exit(EXIT_FAILURE);
+        paused = 1;
+        rs_finished_text = "Hit a key to exit...";
     }
 }
 
@@ -3102,7 +3117,7 @@ check_pixmap_change(int sig)
         imlib_context_set_image(images[image_bg].current->iml->im);
         imlib_free_image_and_decache();
         images[image_bg].current->iml->im = NULL;
-        xterm_seq(XTerm_Pixmap, rs_anim_pixmaps[image_idx++]);
+        xterm_seq(ESCSEQ_XTERM_PIXMAP, rs_anim_pixmaps[image_idx++]);
         last_update = now;
         old_handler = signal(SIGALRM, check_pixmap_change);
         alarm(rs_anim_delay);
@@ -3224,7 +3239,7 @@ cmd_getc(void)
                 RETURN_CHAR();
             }
         }
-        if (paused == 1 && cmd_fd == -1) {
+        if (paused == 1) {
             const char *done = " -- Task Finished, ESC to exit";
 
             append_to_title(rs_finished_title ? rs_finished_title : done);
@@ -3235,6 +3250,8 @@ cmd_getc(void)
             if (rs_finished_text) {
                 cmd_write((unsigned char *) rs_finished_text, strlen(rs_finished_text));
             }
+        } else if (!paused && pipe_fd < 0 && cmd_fd < 0) {
+            exit(0);
         }
 #ifdef SCROLLBAR_BUTTON_CONTINUAL_SCROLLING
         if (scrollbar_uparrow_is_pressed()) {
@@ -3309,12 +3326,28 @@ cmd_getc(void)
 
                 cmdbuf_ptr = cmdbuf_endp = cmdbuf_base;
                 while (count) {
-
                     register int n = read(cmd_fd, cmdbuf_endp, count);
 
-                    if (n <= 0) {
-                        if (paused) {
+                    if (n < 0) {
+                        if (errno == EINTR) {
+                            /* Ignore and continue reading. */
+                            continue;
+                        } else if (errno == EAGAIN) {
+                            /* Stop looping. */
+                            break;
+                        } else {
+                            /* Our file descriptor went bye-bye. */
                             cmd_fd = -1;
+                            if (!paused && (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_PAUSE))) {
+                                paused = 1;
+                            }
+                            break;
+                        }
+                    } else if (n == 0) {
+                        /* EOF */
+                        cmd_fd = -1;
+                        if (!paused && (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_PAUSE))) {
+                            paused = 1;
                         }
                         break;
                     }
@@ -3334,8 +3367,23 @@ cmd_getc(void)
 
                     register int n = read(pipe_fd, cmdbuf_endp, count);
 
-                    if (n <= 0)
+                    if (n < 0) {
+                        if (errno == EINTR) {
+                            /* Ignore and continue reading. */
+                            continue;
+                        } else if (errno == EAGAIN) {
+                            /* Stop looping. */
+                            break;
+                        } else {
+                            /* Our file descriptor went bye-bye. */
+                            pipe_fd = -1;
+                            break;
+                        }
+                    } else if (n == 0) {
+                        /* EOF */
+                        pipe_fd = -1;
                         break;
+                    }
                     n = add_carriage_returns(cmdbuf_endp, n);
                     cmdbuf_endp += n;
                     count -= n;
