@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: events.c,v 1.56 2002/10/13 05:03:46 mej Exp $";
+static const char cvs_ident[] = "$Id: events.c,v 1.64 2004/11/03 23:18:45 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -205,10 +205,12 @@ handle_key_press(event_t *ev)
 
     PROF_INIT(handle_key_press);
     D_EVENTS(("handle_key_press(ev [%8p] on window 0x%08x)\n", ev, ev->xany.window));
+#if UNUSED_BLOCK
     REQUIRE_RVAL(XEVENT_IS_MYWIN(ev, &primary_data), 0);
+#endif
 
     COUNT_EVENT(keypress_cnt);
-    if (!(Options & Opt_no_input)) {
+    if (!(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_NO_INPUT))) {
         lookup_key(ev);
     }
     PROF_DONE(handle_key_press);
@@ -342,7 +344,7 @@ handle_client_message(event_t *ev)
         XGetWindowProperty(Xdisplay, Xroot, props[PROP_DND_SELECTION], 0L, 1000000L, False, AnyPropertyType, &ActualType, &ActualFormat, &Size, &RemainingBytes, &data);
         if (data != NULL) {
             XChangeProperty(Xdisplay, Xroot, XA_CUT_BUFFER0, XA_STRING, 8, PropModeReplace, data, strlen(data));
-            selection_paste(Xroot, XA_CUT_BUFFER0, True);
+            selection_paste(XA_CUT_BUFFER0);
             XSetInputFocus(Xdisplay, Xroot, RevertToNone, CurrentTime);
             XFree(data);
         }
@@ -470,8 +472,8 @@ handle_focus_in(event_t *ev)
                 redraw_image(image_bg);
             }
         }
-        if (Options & Opt_scrollbar_popup) {
-            map_scrollbar(Options & Opt_scrollbar);
+        if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_POPUP)) {
+            map_scrollbar(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR));
         } else {
             scrollbar_set_focus(TermWin.focus);
             scrollbar_draw(IMAGE_STATE_NORMAL, MODE_SOLID);
@@ -498,7 +500,7 @@ handle_focus_out(event_t *ev)
             images[image_bg].current = images[image_bg].disabled;
             redraw_image(image_bg);
         }
-        if (Options & Opt_scrollbar_popup) {
+        if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_POPUP)) {
             map_scrollbar(0);
         } else {
             scrollbar_set_focus(TermWin.focus);
@@ -805,10 +807,15 @@ handle_motion_notify(event_t *ev)
 
     REQUIRE_RVAL(XEVENT_IS_MYWIN(ev, &primary_data), 0);
 
+#ifdef HAVE_TWIN
+    /* It's really silly that Twin uses mouse drag codes that are
+     * different from the ones that xterm uses.
+     */
     if ((PrivateModes & PrivMode_mouse_report) && !(button_state.bypass_keystate)) {
-        mouse_drag_report(&(ev->xbutton));
+        twin_mouse_drag_report(&(ev->xbutton));
         return 1;
     }
+#endif
 
     if (ev->xany.window == TermWin.vt) {
         if (ev->xbutton.state & (Button1Mask | Button3Mask)) {
