@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: font.c,v 1.37 2002/10/08 02:18:08 mej Exp $";
+static const char cvs_ident[] = "$Id: font.c,v 1.43 2004/01/11 22:10:29 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -458,8 +458,12 @@ change_font(int init, const char *fontname)
     D_FONT(("change_font(%d, \"%s\"):  def_font_idx == %u, font_idx == %u\n", init, NONULL(fontname), (unsigned int) def_font_idx, (unsigned int) font_idx));
 
     if (init) {
-        font_idx = def_font_idx;
         ASSERT(etfonts != NULL);
+        if ((def_font_idx >= font_cnt) || (etfonts[def_font_idx] == NULL)) {
+            def_font_idx = font_idx;
+        } else {
+            font_idx = def_font_idx;
+        }
         ASSERT(etfonts[font_idx] != NULL);
 #ifdef MULTI_CHARSET
         ASSERT(etmfonts != NULL);
@@ -584,7 +588,7 @@ change_font(int init, const char *fontname)
         TermWin.fprop = 1;      /* Proportional font */
 
     /* For proportional fonts with large size variations, do some math-fu to try and help the appearance */
-    if (TermWin.fprop && (Options & Opt_proportional) && TermWin.font->per_char && (TermWin.font->max_bounds.width - TermWin.font->min_bounds.width >= 3)) {
+    if (TermWin.fprop && (BITFIELD_IS_SET(vt_options, VT_OPTIONS_PROPORTIONAL)) && TermWin.font->per_char && (TermWin.font->max_bounds.width - TermWin.font->min_bounds.width >= 3)) {
         int cw, n = 0, sum = 0, sumsq = 0, min_w, max_w;
         unsigned int i;
         double dev;
