@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: menus.c,v 1.60 2002/10/13 05:03:46 mej Exp $";
+static const char cvs_ident[] = "$Id: menus.c,v 1.63 2004/06/25 21:52:00 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -461,7 +461,8 @@ menu_t *menu_create(char *title)
         xattr.colormap = cmap;
 
         cursor = XCreateFontCursor(Xdisplay, XC_left_ptr);
-        mask = PointerMotionMask | ButtonMotionMask | ButtonPressMask | ButtonReleaseMask | Button1MotionMask | Button2MotionMask | Button3MotionMask;
+        mask = KeyPressMask | PointerMotionMask | ButtonMotionMask | ButtonPressMask | ButtonReleaseMask
+            | Button1MotionMask | Button2MotionMask | Button3MotionMask;
     }
     menu = (menu_t *) MALLOC(sizeof(menu_t));
     MEMSET(menu, 0, sizeof(menu_t));
