@@ -18,7 +18,7 @@
   * he guarantee anything whatsoever.
   *----------------------------------------------------------------------*/
 
-static const char cvs_ident[] = "$Id: netdisp.c,v 1.7 2002/06/08 15:44:07 mej Exp $";
+static const char cvs_ident[] = "$Id: netdisp.c,v 1.8 2003/06/10 16:20:01 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -94,7 +94,7 @@ network_display(const char *display)
 
         struct ifreq ifr2;
 
-        strcpy(ifr2.ifr_name, ifr->ifr_name);
+        snprintf(ifr2.ifr_name, sizeof(ifr2.ifr_name), ifr->ifr_name);
         if (ioctl(skfd, SIOCGIFADDR, &ifr2) >= 0) {
             unsigned long addr;
             struct sockaddr_in *p_addr;
