@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -28,38 +28,43 @@
 #include <X11/Intrinsic.h>	/* Xlib, Xutil, Xresource, Xfuncproto */
 
 /************ Macros and Definitions ************/
-# define Opt_console                    (1LU <<  0)
-# define Opt_login_shell                (1LU <<  1)
-# define Opt_iconic                     (1LU <<  2)
-# define Opt_visual_bell                (1LU <<  3)
-# define Opt_map_alert                  (1LU <<  4)
-# define Opt_reverse_video              (1LU <<  5)
-# define Opt_write_utmp                 (1LU <<  6)
-# define Opt_scrollbar                  (1LU <<  7)
-# define Opt_meta8                      (1LU <<  8)
-# define Opt_home_on_output             (1LU <<  9)
-# define Opt_scrollbar_right            (1LU << 10)
-# define Opt_borderless                 (1LU << 11)
-# define Opt_no_input                   (1LU << 12)
-# define Opt_no_cursor                  (1LU << 13)
-# define Opt_pause                      (1LU << 14)
-# define Opt_home_on_input              (1LU << 15)
-# define Opt_report_as_keysyms          (1LU << 16)
-# define Opt_xterm_select               (1LU << 17)
-# define Opt_select_whole_line          (1LU << 18)
-# define Opt_scrollbar_popup            (1LU << 19)
-# define Opt_select_trailing_spaces     (1LU << 20)
-# define Opt_install                    (1LU << 21)
-# define Opt_scrollbar_floating         (1LU << 22)
-# define Opt_double_buffer              (1LU << 23)
-# define Opt_mbyte_cursor		(1LU << 24)
-# define Opt_proportional               (1LU << 25)
-# define Opt_resize_gravity             (1LU << 26)
-# define Opt_secondary_screen           (1LU << 27)
+# define VT_OPTIONS_CONSOLE                       (1LU <<  0)
+# define VT_OPTIONS_VISUAL_BELL                   (1LU <<  1)
+# define VT_OPTIONS_MAP_ALERT                     (1LU <<  2)
+# define VT_OPTIONS_REVERSE_VIDEO                 (1LU <<  3)
+# define VT_OPTIONS_META8                         (1LU <<  4)
+# define VT_OPTIONS_HOME_ON_OUTPUT                (1LU <<  5)
+# define VT_OPTIONS_HOME_ON_INPUT                 (1LU <<  6)
+# define VT_OPTIONS_REPORT_AS_KEYSYMS             (1LU <<  7)
+# define VT_OPTIONS_PROPORTIONAL                  (1LU <<  8)
+# define VT_OPTIONS_SECONDARY_SCREEN              (1LU <<  9)
+# define VT_OPTIONS_OVERSTRIKE_BOLD               (1LU << 10)
+# define VT_OPTIONS_BOLD_BRIGHTENS_FOREGROUND     (1LU << 11)
+# define VT_OPTIONS_BLINK_BRIGHTENS_BACKGROUND    (1LU << 12)
+# define VT_OPTIONS_COLORS_SUPPRESS_BOLD          (1LU << 13)
 
-# define IMOPT_TRANS                    (1U << 0)
-# define IMOPT_ITRANS                   (1U << 1)
-# define IMOPT_VIEWPORT                 (1U << 2)
+# define ETERM_OPTIONS_LOGIN_SHELL                (1LU <<  0)
+# define ETERM_OPTIONS_ICONIC                     (1LU <<  1)
+# define ETERM_OPTIONS_WRITE_UTMP                 (1LU <<  2)
+# define ETERM_OPTIONS_SCROLLBAR                  (1LU <<  3)
+# define ETERM_OPTIONS_SCROLLBAR_RIGHT            (1LU <<  4)
+# define ETERM_OPTIONS_BORDERLESS                 (1LU <<  5)
+# define ETERM_OPTIONS_NO_INPUT                   (1LU <<  6)
+# define ETERM_OPTIONS_NO_CURSOR                  (1LU <<  7)
+# define ETERM_OPTIONS_PAUSE                      (1LU <<  8)
+# define ETERM_OPTIONS_XTERM_SELECT               (1LU <<  9)
+# define ETERM_OPTIONS_SELECT_WHOLE_LINE          (1LU << 10)
+# define ETERM_OPTIONS_SCROLLBAR_POPUP            (1LU << 11)
+# define ETERM_OPTIONS_SELECT_TRAILING_SPACES     (1LU << 12)
+# define ETERM_OPTIONS_INSTALL                    (1LU << 13)
+# define ETERM_OPTIONS_SCROLLBAR_FLOATING         (1LU << 14)
+# define ETERM_OPTIONS_DOUBLE_BUFFER              (1LU << 15)
+# define ETERM_OPTIONS_MBYTE_CURSOR               (1LU << 16)
+# define ETERM_OPTIONS_RESIZE_GRAVITY             (1LU << 17)
+
+# define IMAGE_OPTIONS_TRANS                      (1U  <<  0)
+# define IMAGE_OPTIONS_ITRANS                     (1U  <<  1)
+# define IMAGE_OPTIONS_VIEWPORT                   (1U  <<  2)
 
 # define BBAR_FORCE_TOGGLE              (0x03)
 
@@ -71,17 +76,21 @@
 #define PARSE_TRY_NO_THEME              ((unsigned char) 0x04)
 #define PARSE_TRY_ALL                   ((unsigned char) 0x07)
 
-#define to_keysym(p,s)             do { KeySym sym; \
+#define TO_KEYSYM(p,s)             do { KeySym sym; \
                                      if (s && ((sym = XStringToKeysym(s)) != 0)) *p = sym; \
                                    } while (0)
 #define CHECK_VALID_INDEX(i)       (((i) >= image_bg) && ((i) < image_max))
 
 #define RESET_AND_ASSIGN(var, val)  do {if ((var) != NULL) FREE(var);  (var) = (val);} while (0)
 
+#define BITFIELD_SET(var, field)       ((var) |= (field))
+#define BITFIELD_CLEAR(var, field)     ((var) &= ~(field))
+#define BITFIELD_IS_SET(var, field)    ((var) & (field))
+
 /************ Structures ************/
 
 /************ Variables ************/
-extern unsigned long Options, image_toggles;
+extern unsigned long eterm_options, vt_options, image_options;
 extern char *theme_dir, *user_dir;
 extern       char **rs_exec_args;       /* Args to exec (-e or --exec) */
 extern       char  *rs_title;		/* Window title */
@@ -141,7 +150,6 @@ extern KeySym ks_smallfont;
 /************ Function Prototypes ************/
 _XFUNCPROTOBEGIN
 
-unsigned long num_words(const char *str);
 extern char *conf_parse_theme(char **theme, char *conf_name, unsigned char fallback);
 extern void init_libast(void);
 extern void init_defaults(void);
