@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: pixmap.c,v 1.90 2002/10/13 05:28:36 mej Exp $";
+static const char cvs_ident[] = "$Id: pixmap.c,v 1.103 2004/07/14 20:18:29 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -222,15 +222,15 @@ parse_pixmap_ops(char *str)
     D_PIXMAP(("parse_pixmap_ops(str [%s]) called.\n", str));
 
     for (; (token = (char *) strsep(&str, ":"));) {
-        if (!BEG_STRCASECMP("tiled", token)) {
+        if (!BEG_STRCASECMP(token, "tile")) {
             op |= OP_TILE;
-        } else if (!BEG_STRCASECMP("hscaled", token)) {
+        } else if (!BEG_STRCASECMP(token, "hscale")) {
             op |= OP_HSCALE;
-        } else if (!BEG_STRCASECMP("vscaled", token)) {
+        } else if (!BEG_STRCASECMP(token, "vscale")) {
             op |= OP_VSCALE;
-        } else if (!BEG_STRCASECMP("scaled", token)) {
+        } else if (!BEG_STRCASECMP(token, "scale")) {
             op |= OP_SCALE;
-        } else if (!BEG_STRCASECMP("propscaled", token)) {
+        } else if (!BEG_STRCASECMP(token, "propscale")) {
             op |= OP_PROPSCALE;
         }
     }
@@ -256,7 +256,7 @@ set_pixmap_scale(const char *geom, pixmap_t *pmap)
     D_PIXMAP(("scale_pixmap(\"%s\")\n", geom));
     if (!strcmp(geom, "?")) {
         sprintf(str, "[%dx%d+%d+%d]", pmap->w, pmap->h, pmap->x, pmap->y);
-        xterm_seq(XTerm_title, str);
+        xterm_seq(ESCSEQ_XTERM_TITLE, str);
         return 0;
     }
     if ((opstr = strchr(geom, ':')) != NULL) {
@@ -680,7 +680,7 @@ create_trans_pixmap(simage_t *simg, unsigned char which, Drawable d, int x, int
             D_PIXMAP(("Copying %hux%hu rectangle at %d, %d from %ux%u desktop pixmap 0x%08x onto p.\n", width, height, x, y, pw, ph, desktop_pixmap));
             XCopyArea(Xdisplay, desktop_pixmap, p, gc, x, y, width, height, 0, 0);
         }
-        if ((which != image_bg || (image_toggles & IMOPT_ITRANS) || images[image_bg].current != images[image_bg].norm)
+        if ((which != image_bg || (BITFIELD_IS_SET(image_options, IMAGE_OPTIONS_ITRANS)) || images[image_bg].current != images[image_bg].norm)
             && need_colormod(simg->iml)) {
             colormod_trans(p, simg->iml, gc, width, height);
         }
@@ -788,8 +788,12 @@ paste_simage(simage_t *simg, unsigned char which, Window win, Drawable d, unsign
     GC gc;
 
     ASSERT(simg != NULL);
-    REQUIRE(d != None);
     D_PIXMAP(("paste_simage(%8p, %s, 0x%08x, 0x%08x, %hd, %hd, %hd, %hd) called.\n", simg, get_image_type(which), (int) win, (int) d, x, y, w, h));
+
+    REQUIRE(d != None);
+    REQUIRE(w > 0);
+    REQUIRE(h > 0);
+
     if (which != image_max) {
         if (image_mode_is(which, MODE_AUTO) && image_mode_is(which, ALLOW_AUTO)) {
             char buff[255], *reply;
@@ -1087,7 +1091,7 @@ render_simage(simage_t *simg, Window win, unsigned short width, unsigned short h
         }
         simg->pmap->pixmap = create_trans_pixmap(simg, which, win, 0, 0, width, height);
         if (simg->pmap->pixmap != None) {
-            if ((which == image_bg) && (Options & Opt_double_buffer)) {
+            if ((which == image_bg) && (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_DOUBLE_BUFFER))) {
                 copy_buffer_pixmap(MODE_TRANS, (unsigned long) simg->pmap->pixmap, width, height);
                 XSetWindowBackgroundPixmap(Xdisplay, win, buffer_pixmap);
             } else {
@@ -1113,7 +1117,7 @@ render_simage(simage_t *simg, Window win, unsigned short width, unsigned short h
         }
         if (simg->pmap->pixmap != None) {
             D_PIXMAP(("Setting background of window 0x%08x to 0x%08x\n", win, simg->pmap->pixmap));
-            if ((which == image_bg) && (Options & Opt_double_buffer)) {
+            if ((which == image_bg) && (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_DOUBLE_BUFFER))) {
                 copy_buffer_pixmap(MODE_VIEWPORT, (unsigned long) simg->pmap->pixmap, width, height);
                 XSetWindowBackgroundPixmap(Xdisplay, win, buffer_pixmap);
             } else {
@@ -1162,6 +1166,12 @@ render_simage(simage_t *simg, Window win, unsigned short width, unsigned short h
                 xscaled = (unsigned short) ((xsize * x_ratio) * ((float) w / 100.0));
                 yscaled = (unsigned short) ((ysize * x_ratio) * ((float) h / 100.0));
             } else {
+                if (!w && BITFIELD_IS_SET(simg->pmap->op, OP_HSCALE)) {
+                    w = 100;
+                }
+                if (!h && BITFIELD_IS_SET(simg->pmap->op, OP_VSCALE)) {
+                    h = 100;
+                }
                 if (w > 0) {
                     xscaled = width * ((float) w / 100.0);
                 } else {
@@ -1224,7 +1234,7 @@ render_simage(simage_t *simg, Window win, unsigned short width, unsigned short h
                     bevel_pixmap(simg->pmap->pixmap, width, height, simg->iml->bevel->edges, simg->iml->bevel->up);
                 }
                 D_PIXMAP(("Setting background of window 0x%08x to 0x%08x\n", win, simg->pmap->pixmap));
-                if ((which == image_bg) && (Options & Opt_double_buffer)) {
+                if ((which == image_bg) && (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_DOUBLE_BUFFER))) {
                     copy_buffer_pixmap(MODE_VIEWPORT, (unsigned long) simg->pmap->pixmap, width, height);
                     XSetWindowBackgroundPixmap(Xdisplay, win, buffer_pixmap);
                 } else {
@@ -1250,7 +1260,7 @@ render_simage(simage_t *simg, Window win, unsigned short width, unsigned short h
 
     /* Fall back to solid mode if all else fails. */
     if (!image_mode_is(which, MODE_MASK)) {
-        if ((which == image_bg) && (Options & Opt_double_buffer)) {
+        if ((which == image_bg) && (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_DOUBLE_BUFFER))) {
             copy_buffer_pixmap(MODE_SOLID, (unsigned long) PixColors[bgColor], width, height);
             XSetWindowBackgroundPixmap(Xdisplay, win, buffer_pixmap);
         } else {
@@ -2023,7 +2033,7 @@ get_desktop_pixmap(void)
                 D_PIXMAP(("Desktop pixmap has changed.  Updating desktop_pixmap\n"));
                 free_desktop_pixmap();
                 orig_desktop_pixmap = p;
-                if (!(image_toggles & IMOPT_ITRANS) && need_colormod(images[image_bg].current->iml)) {
+                if (!(BITFIELD_IS_SET(image_options, IMAGE_OPTIONS_ITRANS)) && need_colormod(images[image_bg].current->iml)) {
                     int px, py;
                     unsigned int pw, ph, pb, pd;
                     Window w;
@@ -2184,7 +2194,7 @@ set_icon_pixmap(char *filename, XWMHints * pwm_hints)
 
     if (temp_im == NULL) {
         w = h = 48;
-        temp_im = imlib_create_image_using_data(48, 48, (DATA32 *) icon_data);
+        temp_im = imlib_create_image_using_data(48, 48, (DATA32 *) (icon_data + 2));
         imlib_context_set_image(temp_im);
         imlib_image_set_has_alpha(1);
     }
@@ -2193,15 +2203,21 @@ set_icon_pixmap(char *filename, XWMHints * pwm_hints)
     imlib_context_set_dither(1);
     imlib_context_set_blend(0);
     imlib_render_pixmaps_for_whole_image_at_size(&wm_hints->icon_pixmap, &wm_hints->icon_mask, w, h);
-    if (check_for_enlightenment()) {
-        wm_hints->flags |= IconPixmapHint | IconMaskHint;
-    } else {
-        wm_hints->icon_window = XCreateSimpleWindow(Xdisplay, TermWin.parent, 0, 0, w, h, 0, 0L, 0L);
-        shaped_window_apply_mask(wm_hints->icon_window, wm_hints->icon_mask);
-        XSetWindowBackgroundPixmap(Xdisplay, wm_hints->icon_window, wm_hints->icon_pixmap);
-        wm_hints->flags |= IconWindowHint;
-    }
+#ifdef STRICT_ICCCM
+    wm_hints->icon_window = XCreateSimpleWindow(Xdisplay, TermWin.parent, 0, 0, w, h, 0, 0L, 0L);
+    shaped_window_apply_mask(wm_hints->icon_window, wm_hints->icon_mask);
+    XSetWindowBackgroundPixmap(Xdisplay, wm_hints->icon_window, wm_hints->icon_pixmap);
+    wm_hints->flags |= IconWindowHint;
+#else
+    wm_hints->flags |= IconPixmapHint | IconMaskHint;
+#endif
+
+    /* Set the EWMH icon hint for _NET_WM-compliant GNOME WM's. */
+    XChangeProperty(Xdisplay, TermWin.parent,
+                    props[PROP_EWMH_ICON], XA_CARDINAL, 32, PropModeReplace,
+                    (unsigned char *) icon_data, sizeof(icon_data) / sizeof(CARD32));
     imlib_free_image_and_decache();
+
     /* Only set the hints ourselves if we were passed a NULL pointer for pwm_hints */
     if (!pwm_hints) {
         XSetWMHints(Xdisplay, TermWin.parent, wm_hints);
