@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: script.c,v 1.23 2002/10/30 04:44:36 mej Exp $";
+static const char cvs_ident[] = "$Id: script.c,v 1.27 2004/01/11 22:10:29 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -163,7 +163,7 @@ script_handler_copy(char **params)
         for (i = 0; (buffer_id = params[i]) != NULL; i++) {
             if (*buffer_id) {
                 if (*buffer_id >= '0' && *buffer_id <= '7') {
-                    sel = (Atom) ((int) XA_CUT_BUFFER0 + (int) *buffer_id);
+                    sel = (Atom) ((int) XA_CUT_BUFFER0 + (int) (*buffer_id - '0'));
                 } else if (!BEG_STRCASECMP(buffer_id, "clipboard")) {
                     sel = XA_CLIPBOARD(Xdisplay);
                 } else if (!BEG_STRCASECMP(buffer_id, "primary")) {
@@ -264,7 +264,7 @@ script_handler_paste(char **params)
         for (i = 0; (buffer_id = params[i]) != NULL; i++) {
             if (*buffer_id) {
                 if (*buffer_id >= '0' && *buffer_id <= '7') {
-                    sel = (Atom) ((int) XA_CUT_BUFFER0 + (int) *buffer_id);
+                    sel = (Atom) ((int) XA_CUT_BUFFER0 + (int) (*buffer_id - '0'));
                 } else if (!BEG_STRCASECMP(buffer_id, "clipboard")) {
                     sel = XA_CLIPBOARD(Xdisplay);
                 } else if (!BEG_STRCASECMP(buffer_id, "primary")) {
@@ -316,6 +316,8 @@ script_handler_save_buff(char **params)
 {
     if (params && *params) {
         scr_dump_to_file(params[0]);
+    } else {
+        scr_dump();
     }
 }
 
