@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: term.c,v 1.85 2002/10/23 03:03:26 mej Exp $";
+static const char cvs_ident[] = "$Id: term.c,v 1.104 2004/07/14 20:18:30 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -60,7 +60,6 @@ unsigned long SavedModes = PrivMode_Default;
 char *def_colorName[] = {
     "rgb:aa/aa/aa", "rgb:0/0/0",        /* fg/bg */
     "rgb:0/0/0",                /* 0: black             (#000000) */
-#ifndef NO_BRIGHTCOLOR
     /* low-intensity colors */
     "rgb:cc/00/00",             /* 1: red     */
     "rgb:00/cc/00",             /* 2: green   */
@@ -71,7 +70,6 @@ char *def_colorName[] = {
     "rgb:aa/aa/aa",             /* 7: white   */
     /* high-intensity colors */
     "rgb:33/33/33",             /* 8: bright black */
-#endif                          /* NO_BRIGHTCOLOR */
     "rgb:ff/00/00",             /* 1/9:  bright red     */
     "rgb:00/ff/00",             /* 2/10: bright green   */
     "rgb:ff/ff/00",             /* 3/11: bright yellow  */
@@ -290,14 +288,14 @@ lookup_key(XEvent * ev)
         }
         if (len) {
             /* Only home for keypresses with length. */
-            if (Options & Opt_home_on_input) {
+            if (BITFIELD_IS_SET(vt_options, VT_OPTIONS_HOME_ON_INPUT)) {
                 TermWin.view_start = 0;
             }
         }
 
         /* This is a special mode that reports all extended keysyms (above 0xff00) to the application
            as escape sequences.  Very few applications use it, but it can be a handy thing to have. */
-        if ((Options & Opt_report_as_keysyms) && (keysym >= 0xff00)) {
+        if ((BITFIELD_IS_SET(vt_options, VT_OPTIONS_REPORT_AS_KEYSYMS)) && (keysym >= 0xff00)) {
             len = sprintf((char *) kbuf, "\033[k%X;%X~", (unsigned int) (ev->xkey.state & 0xff), (unsigned int) (keysym & 0xff));
             tt_write(kbuf, len);
             LK_RET();
@@ -327,7 +325,7 @@ lookup_key(XEvent * ev)
               LK_RET();
               break;
           case SunXK_Front:
-              xterm_seq(XTerm_Takeover, "");
+              xterm_seq(ESCSEQ_XTERM_TAKEOVER, "");
               LK_RET();
               break;
           default:
@@ -412,10 +410,10 @@ lookup_key(XEvent * ev)
 #ifdef GREEK_SUPPORT
               greek_mode = !greek_mode;
               if (greek_mode) {
-                  xterm_seq(XTerm_title, (greek_getmode() == GREEK_ELOT928 ? "[Greek: iso]" : "[Greek: ibm]"));
+                  xterm_seq(ESCSEQ_XTERM_TITLE, (greek_getmode() == GREEK_ELOT928 ? "[Greek: iso]" : "[Greek: ibm]"));
                   greek_reset();
               } else
-                  xterm_seq(XTerm_title, APL_NAME "-" VERSION);
+                  xterm_seq(ESCSEQ_XTERM_TITLE, APL_NAME "-" VERSION);
               LK_RET();
 #endif
               break;
@@ -431,7 +429,7 @@ lookup_key(XEvent * ev)
         }
 
         /* Process extended keysyms.  This is where the conversion to escape sequences happens. */
-        if (keysym >= 0xff00 && keysym <= 0xffff) {
+        if (keysym >= 0xfe00 && keysym <= 0xffff) {
 #ifdef KEYSYM_ATTRIBUTE
             /* The "keysym" attribute in the config file gets handled here. */
             if (!(shft | ctrl) && KeySym_map[keysym - 0xff00] != NULL) {
@@ -468,7 +466,7 @@ lookup_key(XEvent * ev)
                       kbuf[0] = (((PrivateModes & PrivMode_BackSpace) ? !(shft | ctrl) : (shft | ctrl)) ? '\b' : '\177');
 #endif
 #ifdef MULTI_CHARSET
-                      if ((Options & Opt_mbyte_cursor) && scr_multi2()) {
+                      if ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_MBYTE_CURSOR)) && scr_multi2()) {
                           memmove(kbuf + len, kbuf, len);
                           len *= 2;
                       }
@@ -477,6 +475,7 @@ lookup_key(XEvent * ev)
 
                       /* Tab key is normal unless it's shift-tab. */
                   case XK_Tab:
+                  case XK_ISO_Left_Tab:
                       if (shft) {
                           len = 3;
                           strcpy(kbuf, "\033[Z");
@@ -529,7 +528,7 @@ lookup_key(XEvent * ev)
                           kbuf[2] = ("dacb"[keysym - XK_Left]);
                       }
 #ifdef MULTI_CHARSET
-                      if ((Options & Opt_mbyte_cursor)
+                      if ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_MBYTE_CURSOR))
                           && ((keysym == XK_Left && scr_multi2())
                               || (keysym == XK_Right && scr_multi1()))) {
                           memmove(kbuf + len, kbuf, len);
@@ -623,7 +622,7 @@ lookup_key(XEvent * ev)
 #ifdef KS_DELETE
                       len = strlen(strcpy(kbuf, KS_DELETE));
 #ifdef MULTI_CHARSET
-                      if ((Options & Opt_mbyte_cursor) && scr_multi1()) {
+                      if ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_MBYTE_CURSOR)) && scr_multi1()) {
                           memmove(kbuf + len, kbuf, len);
                           len *= 2;
                       }
@@ -851,7 +850,6 @@ void
 process_print_pipe(void)
 {
     const char *const escape_seq = "\033[4i";
-    const char *const rev_escape_seq = "i4[\033";
     int index;
     FILE *fd;
 
@@ -859,14 +857,18 @@ process_print_pipe(void)
         for (index = 0; index < 4; /* nil */ ) {
             unsigned char ch = cmd_getc();
 
-            if (ch == escape_seq[index])
+            if (ch == escape_seq[index]) {
                 index++;
-            else if (index)
-                for ( /*nil */ ; index > 0; index--)
-                    fputc(rev_escape_seq[index - 1], fd);
+            } else if (index) {
+                int i;
 
-            if (index == 0)
+                for (i = 0; index > 0; i++, index--) {
+                    fputc(escape_seq[i], fd);
+                }
+            }
+            if (index == 0) {
                 fputc(ch, fd);
+            }
         }
         pclose_printer(fd);
     }
@@ -1142,7 +1144,7 @@ process_csi_seq(void)
                 break;
 #endif
             case 8:
-                xterm_seq(XTerm_title, APL_NAME "-" VERSION);
+                xterm_seq(ESCSEQ_XTERM_TITLE, APL_NAME "-" VERSION);
                 break;
             case 9:
 #ifdef PIXMAP_OFFSET
@@ -1164,7 +1166,7 @@ process_csi_seq(void)
                         tint = (tint & 0xffff00) | (images[image_bg].current->iml->bmod->brightness & 0xff);
                     }
                     snprintf(tbuff, sizeof(tbuff), APL_NAME "-" VERSION ":  Transparent - %d%% shading - 0x%06lx tint mask", shading, tint);
-                    xterm_seq(XTerm_title, tbuff);
+                    xterm_seq(ESCSEQ_XTERM_TITLE, tbuff);
                 } else
 #endif
 #ifdef PIXMAP_SUPPORT
@@ -1180,10 +1182,10 @@ process_csi_seq(void)
                         len = strlen(fname) + sizeof(APL_NAME) + sizeof(VERSION) + 5;
                         tbuff = MALLOC(len);
                         snprintf(tbuff, len, APL_NAME "-" VERSION ":  %s", fname);
-                        xterm_seq(XTerm_title, tbuff);
+                        xterm_seq(ESCSEQ_XTERM_TITLE, tbuff);
                         FREE(tbuff);
                     } else {
-                        xterm_seq(XTerm_title, APL_NAME "-" VERSION ":  No Pixmap");
+                        xterm_seq(ESCSEQ_XTERM_TITLE, APL_NAME "-" VERSION ":  No Pixmap");
                     }
                 }
 #endif /* PIXMAP_SUPPORT */
@@ -1297,10 +1299,10 @@ process_xterm_seq(void)
         }
         switch (arg) {
           case 'l':
-              xterm_seq(XTerm_title, (char *) string);
+              xterm_seq(ESCSEQ_XTERM_TITLE, (char *) string);
               break;
           case 'L':
-              xterm_seq(XTerm_iconName, (char *) string);
+              xterm_seq(ESCSEQ_XTERM_ICONNAME, (char *) string);
               break;
           case 'I':
               set_icon_pixmap((char *) string, NULL);
@@ -1322,7 +1324,10 @@ process_window_mode(unsigned int nargs, int args[])
     Window dummy_child;
     int dummy_x, dummy_y;
     unsigned int dummy_border, dummy_depth;
-    char buff[1024], *name;
+    char buff[1024];
+#ifdef ENABLE_NAME_REPORTING_ESCAPES
+    char *name;
+#endif
 
     if (!nargs)
         return;
@@ -1376,7 +1381,8 @@ process_window_mode(unsigned int nargs, int args[])
               BOUND(y, 1, scr->height / TermWin.fheight);
               BOUND(x, 1, scr->width / TermWin.fwidth);
               XResizeWindow(Xdisplay, TermWin.parent,
-                            Width2Pixel(x) + 2 * TermWin.internalBorder + (scrollbar_is_visible()? scrollbar_trough_width() : 0), Height2Pixel(y) + 2 * TermWin.internalBorder);
+                            Width2Pixel(x) + 2 * TermWin.internalBorder + (scrollbar_is_visible()? scrollbar_trough_width() : 0),
+                            Height2Pixel(y) + 2 * TermWin.internalBorder);
               break;
           case 11:
               break;
@@ -1395,6 +1401,7 @@ process_window_mode(unsigned int nargs, int args[])
               snprintf(buff, sizeof(buff), "\033[8;%d;%dt", TERM_WINDOW_GET_REPORTED_ROWS(), TERM_WINDOW_GET_REPORTED_COLS());
               tt_write((unsigned char *) buff, strlen(buff));
               break;
+#ifdef ENABLE_NAME_REPORTING_ESCAPES
           case 20:
               XGetIconName(Xdisplay, TermWin.parent, &name);
               snprintf(buff, sizeof(buff), "\033]L%s\033\\", name);
@@ -1407,6 +1414,7 @@ process_window_mode(unsigned int nargs, int args[])
               tt_write((unsigned char *) buff, strlen(buff));
               XFree(name);
               break;
+#endif
           default:
               break;
         }
@@ -1539,16 +1547,16 @@ process_terminal_mode(int mode, int priv, unsigned int nargs, int arg[])
 #endif
 
                 case 1010:     /* Scroll to bottom on TTY output */
-                    if (Options & Opt_home_on_output)
-                        Options &= ~Opt_home_on_output;
+                    if (BITFIELD_IS_SET(vt_options, VT_OPTIONS_HOME_ON_OUTPUT))
+                        BITFIELD_CLEAR(vt_options, VT_OPTIONS_HOME_ON_OUTPUT);
                     else
-                        Options |= Opt_home_on_output;
+                        BITFIELD_SET(vt_options, VT_OPTIONS_HOME_ON_OUTPUT);
                     break;
                 case 1012:     /* Scroll to bottom on TTY input */
-                    if (Options & Opt_home_on_input)
-                        Options &= ~Opt_home_on_input;
+                    if (BITFIELD_IS_SET(vt_options, VT_OPTIONS_HOME_ON_INPUT))
+                        BITFIELD_CLEAR(vt_options, VT_OPTIONS_HOME_ON_INPUT);
                     else
-                        Options |= Opt_home_on_input;
+                        BITFIELD_SET(vt_options, VT_OPTIONS_HOME_ON_INPUT);
                     break;
 
                 case 1047:     /* Alternate screen & clear */
@@ -1597,30 +1605,45 @@ process_sgr_mode(unsigned int nargs, int arg[])
           case 1:
               scr_rendition(1, RS_Bold);
               break;
+          case 2:
+              scr_rendition(1, RS_Dim);
+              break;
+          case 3:
+              scr_rendition(1, RS_Italic);
+              break;
           case 4:
               scr_rendition(1, RS_Uline);
               break;
           case 5:
               scr_rendition(1, RS_Blink);
               break;
+          case 6:
+              scr_rendition(1, RS_Overscore);
+              break;
           case 7:
               scr_rendition(1, RS_RVid);
               break;
+          case 8:
+              scr_rendition(1, RS_Conceal);
+              break;
           case 22:
               scr_rendition(0, RS_Bold);
+              scr_rendition(0, RS_Dim);
               break;
           case 24:
               scr_rendition(0, RS_Uline);
               break;
           case 25:
               scr_rendition(0, RS_Blink);
+              scr_rendition(0, RS_Overscore);
               break;
           case 27:
               scr_rendition(0, RS_RVid);
               break;
 
+          /* set fg color */
           case 30:
-          case 31:             /* set fg color */
+          case 31:
           case 32:
           case 33:
           case 34:
@@ -1629,12 +1652,14 @@ process_sgr_mode(unsigned int nargs, int arg[])
           case 37:
               scr_color(minColor + (arg[i] - 30), RS_Bold);
               break;
-          case 39:             /* default fg */
+          /* default fg */
+          case 39:
               scr_color(restoreFG, RS_Bold);
               break;
 
+          /* set bg color */
           case 40:
-          case 41:             /* set bg color */
+          case 41:
           case 42:
           case 43:
           case 44:
@@ -1643,14 +1668,47 @@ process_sgr_mode(unsigned int nargs, int arg[])
           case 47:
               scr_color(minColor + (arg[i] - 40), RS_Blink);
               break;
-          case 49:             /* default bg */
+          /* default bg */
+          case 49:
               scr_color(restoreBG, RS_Blink);
               break;
+
+          /* set fg color - bright */
+          case 90:
+          case 91:
+          case 92:
+          case 93:
+          case 94:
+          case 95:
+          case 96:
+          case 97:
+              scr_color(minBright + (arg[i] - 90), RS_Bold);
+              break;
+          /* default fg */
+          case 99:
+              scr_color(restoreFG, RS_Bold);
+              break;
+
+          /* set bg color - bright */
+          case 100:
+          case 101:
+          case 102:
+          case 103:
+          case 104:
+          case 105:
+          case 106:
+          case 107:
+              scr_color(minBright + (arg[i] - 100), RS_Blink);
+              break;
+          /* default bg */
+          case 109:
+              scr_color(restoreBG, RS_Blink);
+              break;
+
         }
 }
 
 /* find if fg/bg matches any of the normal (low-intensity) colors */
-#ifndef NO_BRIGHTCOLOR
 void
 set_colorfgbg(void)
 {
@@ -1709,7 +1767,6 @@ set_colorfgbg(void)
             colorfgbg = SET_BGCOLOR(colorfgbg, i);
     }
 }
-#endif /* NO_BRIGHTCOLOR */
 
 void
 set_title(const char *str)
@@ -1820,10 +1877,15 @@ xterm_seq(int op, const char *str)
 #endif
 
     switch (op) {
-      case XTerm_title:
+      case ESCSEQ_XTERM_NAME: /* 0 */
+          set_title(str);       /* drop */
+      case ESCSEQ_XTERM_ICONNAME: /* 1 */
+          set_icon_name(str);
+          break;
+      case ESCSEQ_XTERM_TITLE: /* 2 */
           set_title(str);
           break;
-      case XTerm_prop:
+      case ESCSEQ_XTERM_PROP: /* 3 */
           if ((nstr = (char *) strsep(&tnstr, ";")) == NULL) {
               break;
           }
@@ -1832,23 +1894,17 @@ xterm_seq(int op, const char *str)
           }
           set_text_property(TermWin.parent, nstr, valptr);
           break;
-      case XTerm_name:
-          set_title(str);       /* drop */
-      case XTerm_iconName:
-          set_icon_name(str);
-          break;
-      case XTerm_Takeover:
+      case ESCSEQ_XTERM_TAKEOVER: /* 5 */
           XSetInputFocus(Xdisplay, TermWin.parent, RevertToParent, CurrentTime);
           XRaiseWindow(Xdisplay, TermWin.parent);
           break;
 
-      case XTerm_EtermSeq:
-
+      case ESCSEQ_XTERM_ETERMSEQ: /* 6 */
           /* Eterm proprietary escape sequences.  See technical reference for details. */
-          D_CMD(("Got XTerm_EtermSeq sequence\n"));
+          D_CMD(("Got ESCSEQ_XTERM_ETERMSEQ sequence\n"));
           nstr = (char *) strsep(&tnstr, ";");
           eterm_seq_op = (unsigned char) strtol(nstr, (char **) NULL, 10);
-          D_CMD(("    XTerm_EtermSeq operation is %d\n", eterm_seq_op));
+          D_CMD(("    ESCSEQ_XTERM_ETERMSEQ operation is %d\n", eterm_seq_op));
           /* Yes, there is order to the numbers for this stuff.  And here it is:
              0-9      Image Class/Mode Configuration
              10-19    Scrollbar/Buttonbar/Menu Configuration
@@ -1977,11 +2033,11 @@ xterm_seq(int op, const char *str)
                         if (iml->mod == NULL) {
                             iml->mod = create_colormod();
                         }
-                        if (!BEG_STRCASECMP("brightness", mod)) {
+                        if (!BEG_STRCASECMP(mod, "brightness")) {
                             iml->mod->brightness = (int) strtol(valptr, (char **) NULL, 0);
-                        } else if (!BEG_STRCASECMP("contrast", mod)) {
+                        } else if (!BEG_STRCASECMP(mod, "contrast")) {
                             iml->mod->contrast = (int) strtol(valptr, (char **) NULL, 0);
-                        } else if (!BEG_STRCASECMP("gamma", mod)) {
+                        } else if (!BEG_STRCASECMP(mod, "gamma")) {
                             iml->mod->gamma = (int) strtol(valptr, (char **) NULL, 0);
                         }
                         update_cmod(iml->mod);
@@ -1994,11 +2050,11 @@ xterm_seq(int op, const char *str)
                         if (iml->rmod == NULL) {
                             iml->rmod = create_colormod();
                         }
-                        if (!BEG_STRCASECMP("brightness", mod)) {
+                        if (!BEG_STRCASECMP(mod, "brightness")) {
                             iml->rmod->brightness = (int) strtol(valptr, (char **) NULL, 0);
-                        } else if (!BEG_STRCASECMP("contrast", mod)) {
+                        } else if (!BEG_STRCASECMP(mod, "contrast")) {
                             iml->rmod->contrast = (int) strtol(valptr, (char **) NULL, 0);
-                        } else if (!BEG_STRCASECMP("gamma", mod)) {
+                        } else if (!BEG_STRCASECMP(mod, "gamma")) {
                             iml->rmod->gamma = (int) strtol(valptr, (char **) NULL, 0);
                         }
                         update_cmod(iml->rmod);
@@ -2011,11 +2067,11 @@ xterm_seq(int op, const char *str)
                         if (iml->gmod == NULL) {
                             iml->gmod = create_colormod();
                         }
-                        if (!BEG_STRCASECMP("brightness", mod)) {
+                        if (!BEG_STRCASECMP(mod, "brightness")) {
                             iml->gmod->brightness = (int) strtol(valptr, (char **) NULL, 0);
-                        } else if (!BEG_STRCASECMP("contrast", mod)) {
+                        } else if (!BEG_STRCASECMP(mod, "contrast")) {
                             iml->gmod->contrast = (int) strtol(valptr, (char **) NULL, 0);
-                        } else if (!BEG_STRCASECMP("gamma", mod)) {
+                        } else if (!BEG_STRCASECMP(mod, "gamma")) {
                             iml->gmod->gamma = (int) strtol(valptr, (char **) NULL, 0);
                         }
                         update_cmod(iml->gmod);
@@ -2028,11 +2084,11 @@ xterm_seq(int op, const char *str)
                         if (iml->bmod == NULL) {
                             iml->bmod = create_colormod();
                         }
-                        if (!BEG_STRCASECMP("brightness", mod)) {
+                        if (!BEG_STRCASECMP(mod, "bright")) {
                             iml->bmod->brightness = (int) strtol(valptr, (char **) NULL, 0);
-                        } else if (!BEG_STRCASECMP("contrast", mod)) {
+                        } else if (!BEG_STRCASECMP(mod, "contrast")) {
                             iml->bmod->contrast = (int) strtol(valptr, (char **) NULL, 0);
-                        } else if (!BEG_STRCASECMP("gamma", mod)) {
+                        } else if (!BEG_STRCASECMP(mod, "gamma")) {
                             iml->bmod->gamma = (int) strtol(valptr, (char **) NULL, 0);
                         }
                         update_cmod(iml->bmod);
@@ -2211,18 +2267,18 @@ xterm_seq(int op, const char *str)
                 break;
             case 11:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_scrollbar_right);
+                OPT_SET_OR_TOGGLE(nstr, eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT);
                 scr_touch();
                 parent_resize();
                 break;
             case 12:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_scrollbar_floating);
+                OPT_SET_OR_TOGGLE(nstr, eterm_options, ETERM_OPTIONS_SCROLLBAR_FLOATING);
                 scrollbar_reposition_and_always_draw();
                 break;
             case 13:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_scrollbar_popup);
+                OPT_SET_OR_TOGGLE(nstr, eterm_options, ETERM_OPTIONS_SCROLLBAR_POPUP);
                 break;
             case 14:
                 nstr = (char *) strsep(&tnstr, ";");
@@ -2239,21 +2295,21 @@ xterm_seq(int op, const char *str)
                 break;
             case 20:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_visual_bell);
+                OPT_SET_OR_TOGGLE(nstr, vt_options, VT_OPTIONS_VISUAL_BELL);
                 break;
 #ifdef MAPALERT_OPTION
             case 21:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_map_alert);
+                OPT_SET_OR_TOGGLE(nstr, vt_options, VT_OPTIONS_MAP_ALERT);
                 break;
 #endif
             case 22:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_xterm_select);
+                OPT_SET_OR_TOGGLE(nstr, eterm_options, ETERM_OPTIONS_XTERM_SELECT);
                 break;
             case 23:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_select_whole_line);
+                OPT_SET_OR_TOGGLE(nstr, eterm_options, ETERM_OPTIONS_SELECT_WHOLE_LINE);
                 break;
             case 24:
                 nstr = (char *) strsep(&tnstr, ";");
@@ -2264,18 +2320,18 @@ xterm_seq(int op, const char *str)
                 break;
             case 25:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_select_trailing_spaces);
+                OPT_SET_OR_TOGGLE(nstr, eterm_options, ETERM_OPTIONS_SELECT_TRAILING_SPACES);
                 break;
             case 26:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_report_as_keysyms);
+                OPT_SET_OR_TOGGLE(nstr, vt_options, VT_OPTIONS_REPORT_AS_KEYSYMS);
                 break;
             case 27:
                 nstr = (char *) strsep(&tnstr, ";");
-                OPT_SET_OR_TOGGLE(nstr, Options, Opt_no_input);
+                OPT_SET_OR_TOGGLE(nstr, eterm_options, ETERM_OPTIONS_NO_INPUT);
                 wm_hints = XGetWMHints(Xdisplay, TermWin.parent);
                 wm_hints->flags |= InputHint;
-                wm_hints->input = ((Options & Opt_no_input) ? False : True);
+                wm_hints->input = ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_NO_INPUT)) ? False : True);
                 XSetWMHints(Xdisplay, TermWin.parent, wm_hints);
                 XFree(wm_hints);
                 break;
@@ -2364,7 +2420,62 @@ xterm_seq(int op, const char *str)
           }
           break;
 
-      case XTerm_Pixmap:
+#ifdef XTERM_COLOR_CHANGE
+      case ESCSEQ_XTERM_FGCOLOR: /* 10 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              set_window_color(fgColor, nstr);
+          }
+          /* drop */
+      case ESCSEQ_XTERM_BGCOLOR: /* 11 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              set_window_color(bgColor, nstr);
+          }
+          /* drop */
+      case ESCSEQ_XTERM_CURSOR_COLOR: /* 12 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+# ifndef NO_CURSORCOLOR
+              set_window_color(cursorColor, nstr);
+# endif
+          }
+          /* drop */
+      case ESCSEQ_XTERM_PTR_FGCOLOR: /* 13 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              set_pointer_colors(nstr, NULL);
+          }
+          /* drop */
+      case ESCSEQ_XTERM_PTR_BGCOLOR: /* 14 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              /* UNSUPPORTED */
+          }
+          /* drop */
+      case ESCSEQ_XTERM_TEK_FGCOLOR: /* 15 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              /* UNSUPPORTED */
+          }
+          /* drop */
+      case ESCSEQ_XTERM_TEK_BGCOLOR: /* 16 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              /* UNSUPPORTED */
+          }
+          /* drop */
+      case ESCSEQ_XTERM_HILIGHT_COLOR: /* 17 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              /* UNSUPPORTED */
+          }
+          /* drop */
+      case ESCSEQ_XTERM_BOLD_COLOR: /* 18 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              set_window_color(colorBD, nstr);
+          }
+          /* drop */
+      case ESCSEQ_XTERM_ULINE_COLOR: /* 19 */
+          if ((nstr = (char *) strsep(&tnstr, ";")) != NULL) {
+              set_window_color(colorUL, nstr);
+          }
+#endif
+          break;
+
+      case ESCSEQ_XTERM_PIXMAP: /* 20 */
 #ifdef PIXMAP_SUPPORT
           FOREACH_IMAGE(if (!image_mode_is(idx, MODE_IMAGE) && image_mode_is(idx, ALLOW_IMAGE)) {
                         image_set_mode(idx, MODE_IMAGE);}
@@ -2395,17 +2506,7 @@ xterm_seq(int op, const char *str)
 #endif /* PIXMAP_SUPPORT */
           break;
 
-      case XTerm_restoreFG:
-#ifdef XTERM_COLOR_CHANGE
-          set_window_color(fgColor, str);
-#endif
-          break;
-      case XTerm_restoreBG:
-#ifdef XTERM_COLOR_CHANGE
-          set_window_color(bgColor, str);
-#endif
-          break;
-      case XTerm_DumpScreen:
+      case ESCSEQ_XTERM_DUMPSCREEN: /* 30 */
 #if 0
           nstr = (char *) strsep(&tnstr, ";");
           if (nstr && *nstr) {
@@ -2413,7 +2514,17 @@ xterm_seq(int op, const char *str)
           }
           break;
 #endif
-      case XTerm_logfile:
+      case ESCSEQ_XTERM_RESTOREFG: /* 39 */
+#ifdef XTERM_COLOR_CHANGE
+          set_window_color(fgColor, str);
+#endif
+          break;
+      case ESCSEQ_XTERM_RESTOREBG: /* 40 */
+#ifdef XTERM_COLOR_CHANGE
+          set_window_color(bgColor, str);
+#endif
+          break;
+      case ESCSEQ_XTERM_LOGFILE: /* 46 */
           nstr = (char *) strsep(&tnstr, ";");
           if (nstr && *nstr && BOOL_OPT_ISTRUE(nstr)) {
               /* Logging on */
@@ -2421,7 +2532,7 @@ xterm_seq(int op, const char *str)
               /* Logging off */
           }
           break;
-      case XTerm_font:
+      case ESCSEQ_XTERM_FONT: /* 50 */
           change_font(0, str);
           break;
       default:
