@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2002, Michael Jennings
+ * Copyright (C) 1997-2004, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: windows.c,v 1.59 2002/10/23 03:03:27 mej Exp $";
+static const char cvs_ident[] = "$Id: windows.c,v 1.67 2004/06/25 21:52:00 mej Exp $";
 
 #include "config.h"
 #include "feature.h"
@@ -331,6 +331,26 @@ process_colors(void)
     stored_palette(SAVE);
 }
 
+void
+set_pointer_colors(const char *fg_name, const char *bg_name)
+{
+    XColor fg, bg;
+
+    if (fg_name != NULL) {
+        fg.pixel = get_color_by_name(fg_name, COLOR_NAME(pointerColor));
+    } else {
+        fg.pixel = PixColors[pointerColor];
+    }
+    XQueryColor(Xdisplay, cmap, &fg);
+    if (bg_name != NULL) {
+        bg.pixel = get_color_by_name(bg_name, COLOR_NAME(bgColor));
+    } else {
+        bg.pixel = PixColors[bgColor];
+    }
+    XQueryColor(Xdisplay, cmap, &bg);
+    XRecolorCursor(Xdisplay, TermWin_cursor, &fg, &bg);
+}
+
 /* Create_Windows() - Open and map the window */
 void
 Create_Windows(int argc, char *argv[])
@@ -345,7 +365,7 @@ Create_Windows(int argc, char *argv[])
     unsigned int width = 0, height = 0;
     MWMHints mwmhints;
 
-    if (Options & Opt_borderless) {
+    if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_BORDERLESS)) {
         prop = XInternAtom(Xdisplay, "_MOTIF_WM_INFO", True);
         if (prop == None) {
             print_warning("Window Manager does not support MWM hints.  Bypassing window manager control for borderless window.\n");
@@ -360,7 +380,7 @@ Create_Windows(int argc, char *argv[])
     }
     Attributes.colormap = cmap;
 
-    szHint.base_width = (2 * TermWin.internalBorder + ((Options & Opt_scrollbar) ? (scrollbar_get_width() + (2 * scrollbar_get_shadow())) : 0));
+    szHint.base_width = (2 * TermWin.internalBorder + ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR)) ? (scrollbar_get_width() + (2 * scrollbar_get_shadow())) : 0));
     szHint.base_height = (2 * TermWin.internalBorder) + bbar_calc_docked_height(BBAR_DOCKED);
 
     flags = (rs_geometry ? XParseGeometry(rs_geometry, &x, &y, &width, &height) : 0);
@@ -409,13 +429,13 @@ Create_Windows(int argc, char *argv[])
 #endif
                                    CWBackPixel | CWBorderPixel | CWColormap | CWOverrideRedirect, &Attributes);
 
-    xterm_seq(XTerm_title, rs_title);
-    xterm_seq(XTerm_iconName, rs_iconName);
+    xterm_seq(ESCSEQ_XTERM_TITLE, rs_title);
+    xterm_seq(ESCSEQ_XTERM_ICONNAME, rs_iconName);
     classHint.res_name = (char *) rs_name;
     classHint.res_class = APL_NAME;
     wmHint.window_group = TermWin.parent;
-    wmHint.input = ((Options & Opt_no_input) ? False : True);
-    wmHint.initial_state = (Options & Opt_iconic ? IconicState : NormalState);
+    wmHint.input = ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_NO_INPUT)) ? False : True);
+    wmHint.initial_state = (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_ICONIC) ? IconicState : NormalState);
     wmHint.window_group = TermWin.parent;
     wmHint.flags = (InputHint | StateHint | WindowGroupHint);
 #ifdef PIXMAP_SUPPORT
@@ -431,32 +451,25 @@ Create_Windows(int argc, char *argv[])
     }
     /* vt cursor: Black-on-White is standard, but this is more popular */
     TermWin_cursor = XCreateFontCursor(Xdisplay, XC_xterm);
-    {
-
-        XColor fg, bg;
-
-        fg.pixel = PixColors[pointerColor];
-        XQueryColor(Xdisplay, cmap, &fg);
-        bg.pixel = PixColors[bgColor];
-        XQueryColor(Xdisplay, cmap, &bg);
-        XRecolorCursor(Xdisplay, TermWin_cursor, &fg, &bg);
-    }
+    set_pointer_colors(NULL, NULL);
 
     /* cursor (menu/scrollbar): Black-on-White */
     cursor = XCreateFontCursor(Xdisplay, XC_left_ptr);
 
     /* the vt window */
-    TermWin.x = (((Options & Opt_scrollbar) && !(Options & Opt_scrollbar_right)) ? (scrollbar_get_width() + (2 * scrollbar_get_shadow())) : 0);
+    TermWin.x = (((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR)) && !(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT))) ? (scrollbar_get_width() + (2 * scrollbar_get_shadow())) : 0);
     TermWin.y = bbar_calc_docked_height(BBAR_DOCKED_TOP);
     TermWin.vt = XCreateWindow(Xdisplay, TermWin.parent, TermWin.x, TermWin.y, szHint.width, szHint.height, 0, Xdepth, InputOutput, CopyFromParent,
                                CWBackPixel | CWBorderPixel | CWOverrideRedirect | CWColormap, &Attributes);
     D_X11(("Created terminal window 0x%08x at %dx%d\n", TermWin.vt, TermWin.x, TermWin.y));
-    if (!(background_is_pixmap()) && !(Options & Opt_borderless)) {
+    if (!(background_is_pixmap()) && !(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_BORDERLESS))) {
         XSetWindowBackground(Xdisplay, TermWin.vt, PixColors[bgColor]);
         XClearWindow(Xdisplay, TermWin.vt);
     }
     XDefineCursor(Xdisplay, TermWin.vt, TermWin_cursor);
-    TermWin.mask = (EnterWindowMask | LeaveWindowMask | ExposureMask | ButtonPressMask | ButtonReleaseMask | Button1MotionMask | Button2MotionMask | Button3MotionMask);
+    TermWin.mask = (KeyPressMask | EnterWindowMask | LeaveWindowMask | ExposureMask
+                    | ButtonPressMask | ButtonReleaseMask | Button1MotionMask
+                    | Button2MotionMask | Button3MotionMask);
     XSelectInput(Xdisplay, TermWin.vt, TermWin.mask);
 
     /* If the user wants a specific desktop, tell the WM that */
@@ -488,7 +501,7 @@ Create_Windows(int argc, char *argv[])
         TermWin.gc = LIBAST_X_CREATE_GC(GCForeground | GCBackground | GCFont | GCGraphicsExposures, &gcvalue);
     }
 
-    if (Options & Opt_no_cursor) {
+    if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_NO_CURSOR)) {
         scr_cursor_visible(0);
     }
 }
@@ -499,7 +512,7 @@ resize_parent(unsigned int width, unsigned int height)
 {
     XWindowAttributes attr;
 
-    if (!(Options & Opt_resize_gravity) || !XGetWindowAttributes(Xdisplay, TermWin.parent, &attr)) {
+    if (!(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_RESIZE_GRAVITY)) || !XGetWindowAttributes(Xdisplay, TermWin.parent, &attr)) {
         XResizeWindow(Xdisplay, TermWin.parent, width, height);
     } else {
         Window junkwin;
@@ -581,7 +594,7 @@ term_resize(int width, int height)
     width = TERM_WINDOW_FULL_WIDTH();
     height = TERM_WINDOW_FULL_HEIGHT();
     XMoveResizeWindow(Xdisplay, TermWin.vt,
-                      ((Options & Opt_scrollbar_right) ? (0) : ((scrollbar_is_visible())? (scrollbar_trough_width()) : (0))),
+                      ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT)) ? (0) : ((scrollbar_is_visible())? (scrollbar_trough_width()) : (0))),
                       bbar_calc_docked_height(BBAR_DOCKED_TOP), width, height);
     if (width != last_width || height != last_height) {
         render_simage(images[image_bg].current, TermWin.vt, width, height, image_bg, 0);
@@ -681,14 +694,8 @@ set_window_color(int idx, const char *color)
         i = atoi(color);
         if (i >= 8 && i <= 15) {        /* bright colors */
             i -= 8;
-# ifndef NO_BRIGHTCOLOR
             PixColors[idx] = PixColors[minBright + i];
-# endif
-        }
-# ifndef NO_BRIGHTCOLOR
-        else
-# endif
-        if (i >= 0 && i <= 7) { /* normal colors */
+        } else if (i >= 0 && i <= 7) { /* normal colors */
             PixColors[idx] = PixColors[minColor + i];
         } else {
             print_warning("Color index %d is invalid.\n", i);
@@ -704,10 +711,10 @@ set_window_color(int idx, const char *color)
         print_warning("Unable to resolve \"%s\" as a color name.\n", color);
         return;
     }
-    redraw_image(image_bg);
     set_colorfgbg();
     scr_touch();
     scr_refresh(DEFAULT_REFRESH);
+    redraw_image(image_bg);
 }
 #endif /* XTERM_COLOR_CHANGE */
 
